@@ -1,6 +1,10 @@
 # Infrastructure for workflowr projects.
 
-# These templates are used by wflow_start().
+# This file defines templates for use with various workflowr functions. They are
+# inserted with `cat(glue::glue(x), file = fname)`, which removes the starting
+# blank line and leaves a final blank line in the output file.
+
+# wflow_start() ----------------------------------------------------------------
 
 templates <- list(
   .gitignore = '
@@ -41,23 +45,20 @@ knit_root_dir: "."
 ',
     `analysis/_site.yml` = '
 name: "{name}"
-output_dir: "../docs"
+output_dir: ../docs
 navbar:
   title: "{name}"
   left:
-    - text: "Home"
-      href: index.html
-    - text: "About"
-      href: about.html
-    - text: "License"
-      href: license.html
-  right:
-    - icon: fa-github
-      href: https://github.com/jdblischak/workflowr
+  - text: Home
+    href: index.html
+  - text: About
+    href: about.html
+  - text: License
+    href: license.html
 output:
   workflowr::wflow_html:
-    toc: true
-    toc_float: true
+    toc: yes
+    toc_float: yes
     theme: cosmo
     highlight: textmate
 
@@ -154,6 +155,8 @@ StripTrailingWhitespace: Yes
 '
 )
 
+# wflow_html() -----------------------------------------------------------------
+
 # These templates are used by wflow_html() to insert HTML before and after the
 # document body.
 
@@ -167,7 +170,6 @@ div.section {
 </style>
 
 ',
-# Curly brackets need to be duplicated to pass through glue::glue
 footer = '
 <!-- Adjust MathJax settings so that all math formulae are shown using
 TeX fonts only; see
@@ -176,18 +178,40 @@ the presentation more consistent at the cost of the webpage sometimes
 taking slightly longer to load. Note that this only works because the
 footer is added to webpages before the MathJax javascript. -->
 <script type="text/x-mathjax-config">
-  MathJax.Hub.Config({{
-    "HTML-CSS": {{ availableFonts: ["TeX"] }}
-  }});
+  MathJax.Hub.Config({
+    "HTML-CSS": { availableFonts: ["TeX"] }
+  });
 </script>
 
-<hr>
-<p>
-  This reproducible <a href="http://rmarkdown.rstudio.com">R Markdown</a>
-  analysis was created with
-  <a href="https://github.com/jdblischak/workflowr">workflowr</a> {wflow_version}
-</p>
-<hr>
-
 '
 )
+
+extras <- list(
+  disable_remote = '
+#!/bin/bash
+
+# This hook prevents pushing to a remote repository, which is ideal for a
+# project containing confidential data. It was created by wflow_start() with the
+# argument disable_remote = TRUE. If you decide you want to be able to push this
+# repository, delete this file.
+
+echo "This is a confidential project. Do not push the files to a remote server"
+exit 1
+
+'
+)
+
+# wflow_use_gitlab() -----------------------------------------------------------
+
+gitlab <- list(`.gitlab-ci.yml` = '
+pages:
+  stage: deploy
+  script:
+    - echo \'Nothing to do...\'
+  artifacts:
+    paths:
+      - public
+  only:
+    - master
+
+')
