@@ -1,10 +1,10 @@
 #' Pull files from remote repository
 #'
-#' \code{wflow_git_pull} pulls the remote files from your remote repository on
-#' GitHub into your repository on your local machine. This is a convenience
-#' function to run Git commands from the R console instead of the Terminal. The
-#' same functionality can be acheived by running \code{git pull} in the
-#' Terminal.
+#' \code{wflow_git_pull} pulls the remote files from your remote repository
+#' online (e.g. GitHub or GitLab) into your repository on your local machine.
+#' This is a convenience function to run Git commands from the R console instead
+#' of the Terminal. The same functionality can be acheived by running \code{git
+#' pull} in the Terminal.
 #'
 #' \code{wflow_git_pull} tries to choose sensible defaults if the user does not
 #' explicitly specify the remote repository and/or the remote branch:
@@ -32,10 +32,10 @@
 #' @param branch character (default: NULL). The name of the branch in the remote
 #'   repository to pull from. If \code{NULL}, the name of the current local
 #'   branch is used.
-#' @param username character (default: NULL). GitHub username. The user is
-#'   prompted if necessary.
-#' @param password character (default: NULL). GitHub password. The user is
-#'   prompted if necessary.
+#' @param username character (default: NULL). Username for online Git hosting
+#'   service (e.g. GitHub or GitLab). The user is prompted if necessary.
+#' @param password character (default: NULL). Password for online Git hosting
+#'   service (e.g. GitHub or GitLab). The user is prompted if necessary.
 #' @param dry_run logical (default: FALSE). Preview the proposed action but do
 #'   not actually pull from the remote repository.
 #' @param project character (default: ".") By default the function assumes the
@@ -51,7 +51,8 @@
 #'
 #' \item \bold{branch}: The branch of the remote repository.
 #'
-#' \item \bold{username}: GitHub username.
+#' \item \bold{username}: Username for online Git hosting service (e.g. GitHub
+#' or GitLab).
 #'
 #' \item \bold{merge_result}: The \code{git_merge_result} object returned by
 #' \link{git2r} (only included if \code{dry_run == FALSE}).
@@ -93,7 +94,7 @@ wflow_git_pull <- function(remote = NULL, branch = NULL, username = NULL,
   if (!(is.character(project) && length(project) == 1))
     stop("project must be a one-element character vector")
 
-  if (!dir.exists(project)) {
+  if (!fs::dir_exists(project)) {
     stop("project directory does not exist.")
   }
 
